==> gimp-2.1.6.tar.bz2: gimp-2.1.6/libgimp/gimpgradients.c <==
/* LIBGIMP - The GIMP Library
 * Copyright (C) 1995-2003 Peter Mattis and Spencer Kimball
 *
 * gimpgradients.c
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "config.h"

#include <string.h>

#include "gimp.h"

/**
 * gimp_gradients_get_gradient:
 *
 * Retrieve the name of the active gradient.
 *
 * This procedure is deprecated! Use 'gimp_context_get_gradient' instead.
 *
 * Returns: The name of the active gradient.
 */
gchar *
gimp_gradients_get_gradient (void)
{
  return gimp_context_get_gradient ();
}

/**
 * gimp_gradients_set_gradient:
 * @name: The name of the gradient to set.
 *
 * Sets the specified gradient as the active gradient.
 *
 * This procedure is deprecated! Use 'gimp_context_set_gradient' instead.
 *
 * Returns: TRUE on success.
 */
gboolean
gimp_gradients_set_gradient (const gchar *name)
{
  return gimp_context_set_gradient (name);
}

==> gimp-2.4.7.tar.bz2: gimp-2.4.7/libgimp/gimpgradients.c <==
/* LIBGIMP - The GIMP Library
 * Copyright (C) 1995-2003 Peter Mattis and Spencer Kimball
 *
 * gimpgradients.c
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "config.h"

#include <string.h>

#include "gimp.h"
#undef GIMP_DISABLE_DEPRECATED
#undef __GIMP_GRADIENTS_H__
#include "gimpgradients.h"

/**
 * gimp_gradients_get_gradient:
 *
 * This procedure is deprecated! Use gimp_context_get_gradient() instead.
 *
 * Returns: The name of the active gradient.
 */
gchar *
gimp_gradients_get_gradient (void)
{
  return gimp_context_get_gradient ();
}

/**
 * gimp_gradients_set_gradient:
 * @name: The name of the gradient to set.
 *
 * This procedure is deprecated! Use gimp_context_set_gradient() instead.
 *
 * Returns: TRUE on success.
 */
gboolean
gimp_gradients_set_gradient (const gchar *name)
{
  return gimp_context_set_gradient (name);
}
